@@ -72,6 +72,9 @@ pub trait BuiltinCommand {
     /// Returns the name of the command, all in uppercase letters.
     fn name(&self) -> &'static str;
 
+    /// Returns the name of the command's category.
+    fn category(&self) -> &'static str;
+
     /// Returns a specification of the command's syntax.
     fn syntax(&self) -> &'static str;
 
@@ -277,6 +280,10 @@ impl BuiltinCommand for ClearCommand {
         "CLEAR"
     }
 
+    fn category(&self) -> &'static str {
+        "Interpreter manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         ""
     }
@@ -320,6 +327,10 @@ pub(crate) mod testutils {
             "IN"
         }
 
+        fn category(&self) -> &'static str {
+            "Testing"
+        }
+
         fn syntax(&self) -> &'static str {
             "variableref"
         }
@@ -369,6 +380,10 @@ pub(crate) mod testutils {
             "OUT"
         }
 
+        fn category(&self) -> &'static str {
+            "Testing"
+        }
+
         fn syntax(&self) -> &'static str {
             "[expr1 [; .. exprN]]"
         }
