@@ -132,6 +132,10 @@ impl BuiltinCommand for DelCommand {
         "DEL"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         "filename"
     }
@@ -174,6 +178,10 @@ impl BuiltinCommand for DirCommand {
         "DIR"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         ""
     }
@@ -207,6 +215,10 @@ impl BuiltinCommand for EditCommand {
         "EDIT"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         "[lineno%]"
     }
@@ -243,6 +255,10 @@ impl BuiltinCommand for LoadCommand {
         "LOAD"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         "filename"
     }
@@ -286,6 +302,10 @@ impl BuiltinCommand for NewCommand {
         "NEW"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         ""
     }
@@ -319,6 +339,10 @@ impl BuiltinCommand for RunCommand {
         "RUN"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         ""
     }
@@ -354,6 +378,10 @@ impl BuiltinCommand for SaveCommand {
         "SAVE"
     }
 
+    fn category(&self) -> &'static str {
+        "Stored program manipulation"
+    }
+
     fn syntax(&self) -> &'static str {
         "filename"
     }
